@@ -2,7 +2,7 @@
 <!DOCTYPE helpset
   PUBLIC "-//Sun Microsystems Inc.//DTD JavaHelp HelpSet Version 1.0//EN" "http://java.sun.com/products/javahelp/helpset_1_0.dtd">
 <helpset version="1.0">
-<title>SciGetFem</title>
+<title>sci_getfem</title>
 <maps>
 <homeID>top</homeID>
 <mapref location="jhelpmap.jhm"/>
